==> orthanc_1.3.1+dfsg.orig.tar.xz: Orthanc-1.3.1/Plugins/Engine/PluginsEnumerations.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017 Osimis, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#if ORTHANC_ENABLE_PLUGINS == 1

#include "../Include/orthanc/OrthancCPlugin.h"
#include "../../OrthancServer/ServerEnumerations.h"

namespace Orthanc
{
  namespace Plugins
  {
    OrthancPluginResourceType Convert(ResourceType type);

    ResourceType Convert(OrthancPluginResourceType type);

    OrthancPluginChangeType Convert(ChangeType type);

    OrthancPluginPixelFormat Convert(PixelFormat format);

    PixelFormat Convert(OrthancPluginPixelFormat format);

    OrthancPluginContentType Convert(FileContentType type);

    FileContentType Convert(OrthancPluginContentType type);

    DicomToJsonFormat Convert(OrthancPluginDicomToJsonFormat format);

    OrthancPluginIdentifierConstraint Convert(IdentifierConstraintType constraint);

    IdentifierConstraintType Convert(OrthancPluginIdentifierConstraint constraint);

    OrthancPluginInstanceOrigin Convert(RequestOrigin origin);

    OrthancPluginHttpMethod Convert(HttpMethod method);

    ValueRepresentation Convert(OrthancPluginValueRepresentation vr);

    OrthancPluginValueRepresentation Convert(ValueRepresentation vr);
  }
}

#endif

==> orthanc_1.5.4+dfsg.orig.tar.xz: Orthanc-1.5.4/Plugins/Engine/PluginsEnumerations.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2019 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#if ORTHANC_ENABLE_PLUGINS == 1

/**
 * NB: Conversions to/from "OrthancPluginConstraintType" and
 * "OrthancPluginResourceType" are located in file
 * "../../OrthancServer/Search/DatabaseConstraint.h" to be shared with
 * the "orthanc-databases" project.
 **/

#include "../Include/orthanc/OrthancCPlugin.h"
#include "../../OrthancServer/Search/DatabaseConstraint.h"

namespace Orthanc
{
  namespace Compatibility
  {
    OrthancPluginIdentifierConstraint Convert(IdentifierConstraintType constraint);

    IdentifierConstraintType Convert(OrthancPluginIdentifierConstraint constraint);
  }

  namespace Plugins
  {
    OrthancPluginChangeType Convert(ChangeType type);

    OrthancPluginPixelFormat Convert(PixelFormat format);

    PixelFormat Convert(OrthancPluginPixelFormat format);

    OrthancPluginContentType Convert(FileContentType type);

    FileContentType Convert(OrthancPluginContentType type);

    DicomToJsonFormat Convert(OrthancPluginDicomToJsonFormat format);

    OrthancPluginInstanceOrigin Convert(RequestOrigin origin);

    OrthancPluginHttpMethod Convert(HttpMethod method);

    ValueRepresentation Convert(OrthancPluginValueRepresentation vr);

    OrthancPluginValueRepresentation Convert(ValueRepresentation vr);

    OrthancPluginJobStepStatus Convert(JobStepCode step);

    JobStepCode Convert(OrthancPluginJobStepStatus step);
  }
}

#endif
